==> haskell-json-ast-0.3.2-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 json-ast
version:              0.3.2
visibility:           public
id:                   json-ast-0.3.2-5yR07XuvmxdDz9Ruhumg5i
key:                  json-ast-0.3.2-5yR07XuvmxdDz9Ruhumg5i
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/json-ast 
synopsis:             Universal JSON AST datastructure
description:
    This library provides only a data-type representing the JSON value tree.
    It is intended to be used as a shared data-type by all kinds of JSON libraries.
    Same as we have the \"xml-types\" package for libraries dealing with XML.

    Now, since the \"aeson\" @Value@ has been serving this purpose for years,
    we'\''ve intentionally made this type representationally identical to it,
    making it possible to convert between them at 0 runtime cost.
    This means that we can use those types interchangeably,
    making it possible to gradually migrate.

    ===Why displace the \"aeson\" @Value@?

    1. To boost the competition between JSON libraries.
    Instead of nudging the community to implement its ideas by patching \"aeson\".
    After all, competition is the driving force of evolution and hence progress.

    2. Due to so much patching already happening to \"aeson\",
    its loss of focus, some questionable design and
    strive for backwards compatibility, it'\''s becoming bloated.
    IOW, it'\''s trying to be "everything JSON" but with no careful design or plan and
    it'\''s tied by its past.
    With these restrictions it'\''s impossible for \"aeson\" to ever become a polished
    library.

abi:                  6e51c9bdf601a5b6d0f996c488904ad9
exposed:              True
exposed-modules:      JSONAST
import-dirs:          /usr/lib/ghc-9.4.8/site-local/json-ast-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/json-ast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/json-ast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json-ast
hs-libraries:         HSjson-ast-0.3.2-5yR07XuvmxdDz9Ruhumg5i
depends:
    base-4.17.2.1 scientific-0.3.8.0-Csy6naPBtz6IxA0BF8lmor text-2.0.2
    unordered-containers-0.2.20-8z8yrOH3Dwd8Gc78vZRE2k
    vector-0.13.2.0-C8nzmtHpFSiD5klMFr8FFK

haddock-interfaces:   /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html:         /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-ast-0.3.2-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 json-ast
version:              0.3.2
visibility:           public
id:                   json-ast-0.3.2-2qmySEooTUF6xJaXhwXMcm
key:                  json-ast-0.3.2-2qmySEooTUF6xJaXhwXMcm
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/json-ast 
synopsis:             Universal JSON AST datastructure
description:
    This library provides only a data-type representing the JSON value tree.
    It is intended to be used as a shared data-type by all kinds of JSON libraries.
    Same as we have the \"xml-types\" package for libraries dealing with XML.

    Now, since the \"aeson\" @Value@ has been serving this purpose for years,
    we'\''ve intentionally made this type representationally identical to it,
    making it possible to convert between them at 0 runtime cost.
    This means that we can use those types interchangeably,
    making it possible to gradually migrate.

    ===Why displace the \"aeson\" @Value@?

    1. To boost the competition between JSON libraries.
    Instead of nudging the community to implement its ideas by patching \"aeson\".
    After all, competition is the driving force of evolution and hence progress.

    2. Due to so much patching already happening to \"aeson\",
    its loss of focus, some questionable design and
    strive for backwards compatibility, it'\''s becoming bloated.
    IOW, it'\''s trying to be "everything JSON" but with no careful design or plan and
    it'\''s tied by its past.
    With these restrictions it'\''s impossible for \"aeson\" to ever become a polished
    library.

abi:                  78cf057e093bbf0a9e2502c38198ca7a
exposed:              True
exposed-modules:      JSONAST
import-dirs:          /usr/lib/ghc-9.4.8/site-local/json-ast-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/json-ast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/json-ast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json-ast
hs-libraries:         HSjson-ast-0.3.2-2qmySEooTUF6xJaXhwXMcm
depends:
    base-4.17.2.1 scientific-0.3.8.0-EroasVwH8ulAVKZ9SvWekK text-2.0.2
    unordered-containers-0.2.20-DjNgsRwGYvfHy5WsKzKUzR
    vector-0.13.2.0-FmAyOUuMvM2EH0h3dDhWXJ

haddock-interfaces:   /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html:         /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
